@@ -8,7 +8,7 @@ use Perl::Critic::Utils qw(:severities :classification :ppi);
 use Perl::Critic::Violation;
 use parent 'Perl::Critic::Policy';
 
-our $VERSION = '0.019';
+our $VERSION = '0.020';
 
 sub supported_parameters { () }
 sub default_severity { $SEVERITY_HIGH }
@@ -43,12 +43,12 @@ my %features = (
 	'POSIX::tmpnam()' => {
 		expl => 'The tmpnam() function from POSIX is deprecated in perl v5.22.0. Use File::Temp instead.',
 	},
-	'qr//xx' => {
-		expl => 'Use of multiple /x regular expression pattern modifiers is deprecated in perl v5.22.0.',
-	},
 	'qw(...) as parentheses' => {
 		expl => 'Use of qw(...) as parentheses is deprecated in perl v5.14.0. Wrap the list in literal parentheses when required, such as in a foreach loop.',
 	},
+	'require ::Foo::Bar' => {
+		expl => 'Bareword require starting with a double colon is an error in perl v5.26.0.',
+	},
 	'UNIVERSAL->import()' => {
 		expl => 'The method UNIVERSAL->import() (or passing import arguments to "use UNIVERSAL") is deprecated in perl v5.12.0.',
 	},
@@ -75,14 +75,18 @@ sub violates {
 	my @args;
 	my @violations;
 	if ($elem->isa('PPI::Statement')) {
-		# use UNIVERSAL ...;
 		if ($elem->isa('PPI::Statement::Include')) {
-			if ($elem->type eq 'use' and $elem->module eq 'UNIVERSAL') {
+			# use UNIVERSAL ...;
+			if ($elem->type eq 'use' and defined $elem->module and $elem->module eq 'UNIVERSAL') {
 				my @args = $elem->arguments;
 				if (!@args or !$args[0]->isa('PPI::Structure::List') or $args[0]->schildren) {
 					push @violations, $self->_violation('UNIVERSAL->import()', $elem);
 				}
 			}
+			# require ::Foo::Bar
+			if (defined $elem->module and $elem->module =~ m/^::/) {
+				push @violations, $self->_violation('require ::Foo::Bar', $elem);
+			}
 		}
 	} elsif ($elem->isa('PPI::Token')) {
 		if ($elem->isa('PPI::Token::Symbol')) {
@@ -182,13 +186,9 @@ sub violates {
 				push @violations, $self->_violation('?PATTERN?', $elem);
 			}
 			if (!$elem->isa('PPI::Token::Regexp::Transliterate')) {
-				push @violations, $self->_violates_regex($elem);
 				push @violations, $self->_violates_interpolated($elem);
 			}
 		} elsif ($elem->isa('PPI::Token::QuoteLike')) {
-			if ($elem->isa('PPI::Token::QuoteLike::Regexp')) {
-				push @violations, $self->_violates_regex($elem);
-			}
 			if ($elem->isa('PPI::Token::QuoteLike::Regexp') or $elem->isa('PPI::Token::QuoteLike::Backtick') or $elem->isa('PPI::Token::QuoteLike::Command')) {
 				push @violations, $self->_violates_interpolated($elem);
 			}
@@ -201,18 +201,6 @@ sub violates {
 	return @violations;
 }
 
-sub _violates_regex {
-	my ($self, $elem) = @_;
-	my @violations;
-	# qr//xx
-	# get_modifiers puts the modifiers in a hash, so we need to parse the modifiers ourselves
-	my ($delim_first, $delim_second) = $elem->get_delimiters;
-	my $ending_delim = quotemeta substr +($delim_second // $delim_first), 1, 1;
-	(my $modifiers = $elem) =~ s/^.*$ending_delim//s;
-	push @violations, $self->_violation('qr//xx', $elem) if $modifiers =~ m/x.*x/s;
-	return @violations;
-}
-
 sub _violates_interpolated {
 	my ($self, $elem) = @_;
 	my @violations;
@@ -313,18 +301,19 @@ functions can be replaced with appropriate regex matches.
 The C<tmpnam()> function from L<POSIX>.pm is deprecated in perl v5.22.0 and
 removed in perl v5.26.0. Use L<File::Temp> instead.
 
-=head2 qr//xx
-
-Use of multiple C</x> regular expression pattern modifiers on a single pattern
-is deprecated in perl v5.22.0 and an error in perl v5.26.0. This syntax
-previously had no extra effect.
-
 =head2 qw(...) as parentheses
 
 Literal parentheses are required for certain statements such as a
 C<for my $foo (...) { ... }> construct. Using a C<qw(...)> list literal without
-surrounding parentheses in this syntax is deprecated in perl v5.14.0. Wrap the
-literal in parentheses: C<for my $foo (qw(...)) { ... }>.
+surrounding parentheses in this syntax is deprecated in perl v5.14.0 and a
+syntax error in perl v5.18.0. Wrap the literal in parentheses:
+C<for my $foo (qw(...)) { ... }>.
+
+=head2 require ::Foo::Bar
+
+A bareword C<require> (or C<use>) starting with a double colon would
+inadvertently translate to a path starting with C</>. Starting in perl v5.26.0,
+this is a fatal error.
 
 =head2 UNIVERSAL->import()
 
